@@ -5,22 +5,22 @@
  * Copyright (c) 1998, 1999 Kungliga Tekniska Högskolan
  * (Royal Institute of Technology, Stockholm, Sweden).
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 
+ *
  * 1. Redistributions of source code must retain the above copyright
  *    notice, this list of conditions and the following disclaimer.
- * 
+ *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 
+ *
  * 3. Neither the name of the Institute nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -78,12 +78,6 @@ enum protection_level name_to_level(const char *name)
 static struct sec_client_mech *mechs[] = {
 #ifdef HAVE_KRB5
 	&gss_client_mech,
-#endif
-#ifdef HAVE_KRB4
-	&krb4_client_mech,
-#endif
-#ifdef USE_SSL
-	&ssl_client_mech,
 #endif
 	NULL
 };
@@ -216,7 +210,7 @@ int sec_read(int fd, void *data, int length)
 	return rx;
 }
 
-static int sec_send(int fd, char *from, int length)
+static int sec_send(int fd, const char *from, int length)
 {
 	int bytes;
 	void *buf;
@@ -244,7 +238,7 @@ int sec_fflush(FILE * F)
 	return 0;
 }
 
-int sec_write(int fd, char *data, int length)
+int sec_write(int fd, const char* data, int length)
 {
 	int len = ftp->buffer_size;
 	int tx = 0;
@@ -313,7 +307,7 @@ int sec_read_msg(char *s, int level)
 	int code;
 
 	buf = malloc(strlen(s));
-	len = base64_decode(s + 4, buf);	/* XXX */
+	len = b64_decode(s + 4, buf);	/* XXX */
 
 	len = (*ftp->mech->decode) (ftp->app_data, buf, len, level);
 	if (len < 0)
@@ -353,7 +347,7 @@ int sec_vfprintf(FILE * f, const char *fmt, va_list ap)
 		printf(_("Failed to encode command.\n"));
 		return -1;
 	}
-	if (base64_encode(enc, len, &buf) < 0) {
+	if (b64_encode(enc, len, &buf) < 0) {
 		printf(_("Out of memory base64-encoding.\n"));
 		return -1;
 	}
