@@ -23,7 +23,6 @@
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
-#include "bashline.h"
 
 #if defined(BUFSIZ) && BUFSIZ >= 131072
 #define SSH_BUFSIZ BUFSIZ
@@ -31,7 +30,9 @@
 #define SSH_BUFSIZ 131072
 #endif
 
+#ifndef MIN
 #define MIN(a,b) (a) < (b) ? (a) : (b)
+#endif
 
 /* from libssh examples */
 static int verify_knownhost(ssh_session session)
@@ -58,16 +59,16 @@ static int verify_knownhost(ssh_session session)
       return -1;
 
     case SSH_SERVER_FOUND_OTHER:
-      fprintf(stderr, _("The host key for this server was not found but an other"
-        "type of key exists.\n"));
-      fprintf(stderr, _("An attacker might change the default server key to"
+      fprintf(stderr, _("The host key for this server was not found but an "
+        "other type of key exists.\n"));
+      fprintf(stderr, _("An attacker might change the default server key to "
         "confuse your client into thinking the key does not exist\n"));
       free(hash);
       return -1;
 
     case SSH_SERVER_FILE_NOT_FOUND:
       fprintf(stderr, _("Could not find known host file.\n"));
-      fprintf(stderr, _("If you accept the host key here, the file will be"
+      fprintf(stderr, _("If you accept the host key here, the file will be "
        "automatically created.\n"));
       /* fallback to SSH_SERVER_NOT_KNOWN behavior */
 
@@ -609,7 +610,7 @@ void ssh_pwd(void)
 }
 
 static int do_scp_read(ssh_scp scp, const char* infile, FILE* fp,
-                       getmode_t mode, ftp_transfer_func hookf)
+                       transfer_mode_t mode, ftp_transfer_func hookf)
 {
   time_t then = time(NULL) - 1;
   ftp_set_close_handler();
@@ -683,12 +684,12 @@ static int do_scp_read(ssh_scp scp, const char* infile, FILE* fp,
   return r;
 }
 
-static int do_read(const char* infile, FILE* fp, getmode_t mode,
+static int do_read(const char* infile, FILE* fp, transfer_mode_t mode,
                    ftp_transfer_func hookf, uint64_t offset)
 {
   if (gvSSHTrySCP && !offset)
   {
-    char* escaped = bash_backslash_quote(infile);
+    char* escaped = backslash_quote(infile);
     /* try to set up a scp connection */
     ssh_scp scp = ssh_scp_new(ftp->session, SSH_SCP_READ, escaped);
     free(escaped);
@@ -780,7 +781,7 @@ static int do_read(const char* infile, FILE* fp, getmode_t mode,
   return r;
 }
 
-int ssh_do_receive(const char *infile, FILE *fp, getmode_t mode,
+int ssh_do_receive(const char *infile, FILE *fp, transfer_mode_t mode,
                    ftp_transfer_func hookf)
 {
   uint64_t offset = ftp->restart_offset;
