@@ -19,7 +19,6 @@
 #include "strq.h"
 #include "shortpath.h"
 #include "utils.h"
-#include "bashline.h"
 
 #ifdef HAVE_REGEX_H
 # include <regex.h>
@@ -116,7 +115,6 @@ static int do_the_fxp(Ftp *srcftp, const char *src,
 					  Ftp *destftp, const char *dest,
 					  fxpmode_t how, unsigned opt)
 {
-	int r;
 	transfer_mode_t type;
 
 	if(test(opt, FXP_NOHUP))
@@ -135,7 +133,7 @@ static int do_the_fxp(Ftp *srcftp, const char *src,
 	if(test(opt, FXP_VERBOSE)) {
 		printf("%s\n", src);
 	}
-	r = ftp_fxpfile(srcftp, src, destftp, dest, how, type);
+	const int r = ftp_fxpfile(srcftp, src, destftp, dest, how, type);
 #if 0 && (defined(HAVE_SETPROCTITLE) || defined(linux))
 	if(gvUseEnvString && ftp_connected())
 		setproctitle("%s", srcftp->url->hostname);
@@ -158,7 +156,6 @@ static int fxpfile(const rfile *fi, unsigned int opt,
 	fxpmode_t how = fxpNormal;
 	bool file_exists = false;
 	char *dest, *dpath;
-	int r;
 	bool dir_created;
 	char *dest_dir, *q_dest_dir;
 	Ftp *thisftp = ftp;
@@ -201,8 +198,8 @@ static int fxpfile(const rfile *fi, unsigned int opt,
 	/* make sure destination directory exists */
 	dpath = base_dir_xptr(dest);
 	dest_dir = ftp_path_absolute(dpath);
-	q_dest_dir = bash_backslash_quote(dest_dir);
-	r = ftp_mkpath(q_dest_dir);
+	q_dest_dir = backslash_quote(dest_dir);
+	int r = ftp_mkpath(q_dest_dir);
 	free(q_dest_dir);
 	free(dest_dir);
 	if(r == -1) {
@@ -347,7 +344,6 @@ static void fxpfiles(list *gl, unsigned int opt, const char *output)
 	rfile *fp, *lnfp;
 	const char *opath, *ofile;
 	char *link = 0;
-	int r;
 
 	list_sort(gl, get_sort_func, false);
 
@@ -391,8 +387,6 @@ static void fxpfiles(list *gl, unsigned int opt, const char *output)
 			/* else a==ASKYES */
 		}
 
-		r = 0;
-
 		if(rislink(fp)) {
 			link_to_link__duh:
 			{
@@ -407,7 +401,7 @@ static void fxpfiles(list *gl, unsigned int opt, const char *output)
 			if(lnfp == 0) {
 				/* couldn't dereference the link, try to RETR it */
 				ftp_trace("unable to dereference link\n");
-				r = fxpfile(fp, opt, output, ofile);
+				int r = fxpfile(fp, opt, output, ofile);
 				transfer_nextfile(gl, &li, r == 0);
 				continue;
 			}
@@ -469,7 +463,7 @@ static void fxpfiles(list *gl, unsigned int opt, const char *output)
 			        continue;
             }
 
-						char* q_recurs_mask = bash_backslash_quote(recurs_mask);
+						char* q_recurs_mask = backslash_quote(recurs_mask);
             list* rgl = rglob_create();
 						rglob_glob(rgl, q_recurs_mask, true, true,
 								   fxp_exclude_func);
@@ -498,7 +492,7 @@ static void fxpfiles(list *gl, unsigned int opt, const char *output)
 			transfer_nextfile(gl, &li, true);
 			continue;
 		}
-		r = fxpfile(fp, opt, output, ofile);
+		const int r = fxpfile(fp, opt, output, ofile);
 
 		transfer_nextfile(gl, &li, r == 0);
 
