@@ -16,13 +16,11 @@
 #include "gvars.h"
 #include "strq.h"
 #include "input.h"
-#include "makepath.h"
 #include "shortpath.h"
 #include "transfer.h"
 #include "commands.h"
-#include <modechange.h>  /* in ../lib/ */
+#include "utils/modechange.h"
 #include "utils.h"
-#include "bashline.h"
 
 #ifdef HAVE_REGEX_H
 # include <regex.h>
@@ -31,7 +29,7 @@
 static bool get_quit = false;
 static bool get_owbatch = false;
 static bool get_delbatch = false;
-static struct mode_change *cmod = 0;
+static mode_change *cmod = 0;
 static gid_t group_change = -1;
 static bool get_skip_empty = false;
 
@@ -48,7 +46,9 @@ static void print_get_syntax(void)
 {
   show_help(_("Receives files from remote."), "get [options] files",
     _("  -a, --append         append if destination exists\n"
-      "  -c, --chmod=PERM     change mode of transferred files to PERM\n"
+      "  -c, --chmod=PERM     change mode of transferred files to PERM;\n"
+      "                       PERM can be permissions in its octal representation\n"
+      "                       or of the form [ugoa]*[+-=][rwxXstugo]+ separated by commas\n"
       "      --chgrp=GROUP    change group of transferred files to GROUP\n"
       "  -d, --no-dereference copy symbolic links as symbolic links\n"
       "  -D, --delete-after   delete remote file after successful transfer\n"
@@ -93,7 +93,6 @@ static bool get_exclude_func(rfile *f)
 static int do_the_get(const char *src, const char *dest,
                       putmode_t how, unsigned opt)
 {
-    int r = 0;
     char *fulldest;
     char *tmp;
     transfer_mode_t type;
@@ -115,10 +114,10 @@ static int do_the_get(const char *src, const char *dest,
         setproctitle("%s, get %s", ftp->url->hostname, src);
 #endif
 
-    r = ftp_getfile(src, dest, how, type,
-                    test(opt, GET_VERBOSE)
-                    && !gvSighupReceived
-                    && !test(opt, GET_NOHUP) ? transfer : 0);
+    int r = ftp_getfile(src, dest, how, type,
+                        test(opt, GET_VERBOSE)
+                        && !gvSighupReceived
+                        && !test(opt, GET_NOHUP) ? transfer : 0);
 
     if(r == 0 && (test(opt, GET_NOHUP) || gvSighupReceived)) {
         fprintf(stderr, "%s [%sb of ",
@@ -227,8 +226,12 @@ static int getfile(const rfile *fi, unsigned int opt,
     {
         char *destdir = base_dir_xptr(dest);
         if(destdir) {
-            int r = make_path(destdir, S_IRWXU, S_IRWXU, -1, -1, 1, 0);
-            if(r != 0) {
+            bool r = make_path(destdir);
+            if(!r) {
+                if (errno == EEXIST)
+                  ftp_err("`%s' exists but is not a directory\n", destdir);
+                else
+                  ftp_err("%s: %s\n", destdir, strerror(errno));
                 transfer_mail_msg(_("Couldn't create directory: %s\n"),
                                   destdir);
                 free(destdir);
@@ -416,7 +419,6 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
     rfile *fp, *lnfp;
     const char *opath, *ofile;
     char *link = 0;
-    int r;
 
     list_sort(gl, get_sort_func, false);
 
@@ -459,13 +461,12 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
             /* else a==ASKYES */
         }
 
-        r = 0;
 
         if(rislink(fp)) {
             link_to_link__duh:
             if(test(opt, GET_NO_DEREFERENCE)) {
                 /* link the file, don't copy */
-                r = getfile(fp, opt, output, ofile);
+                const int r = getfile(fp, opt, output, ofile);
                 transfer_nextfile(gl, &li, r == 0);
                 continue;
             }
@@ -482,7 +483,7 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
             if(lnfp == 0) {
                 /* couldn't dereference the link, try to RETR it */
                 ftp_trace("unable to dereference link\n");
-                r = getfile(fp, opt, output, ofile);
+                const int r = getfile(fp, opt, output, ofile);
                 transfer_nextfile(gl, &li, r == 0);
                 continue;
             }
@@ -547,7 +548,7 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
                           continue;
                         }
                         rgl = rglob_create();
-                        q_recurs_mask = bash_backslash_quote(recurs_mask);
+                        q_recurs_mask = backslash_quote(recurs_mask);
                         rglob_glob(rgl, q_recurs_mask, true, true, get_exclude_func);
                         free(q_recurs_mask);
                         if(list_numitem(rgl) > 0)
@@ -574,7 +575,7 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
             transfer_nextfile(gl, &li, true);
             continue;
         }
-        r = getfile(fp, opt, output, ofile);
+        const int r = getfile(fp, opt, output, ofile);
 
         transfer_nextfile(gl, &li, r == 0);
 
@@ -679,17 +680,11 @@ void cmd_get(int argc, char **argv)
             opt |= GET_APPEND;
             break;
           case 'c':
-            cmod = mode_compile(optarg,
-                                (MODE_MASK_EQUALS | MODE_MASK_PLUS
-                                 | MODE_MASK_MINUS));
-            if(cmod == MODE_INVALID) {
+            cmod = mode_compile(optarg, MODE_MASK_ALL);
+            if(cmod == NULL) {
                 fprintf(stderr, _("Invalid mode for --chmod: %s\n"), optarg);
                 return;
             }
-            else if (cmod == MODE_MEMORY_EXHAUSTED) {
-                fprintf(stderr, _("virtual memory exhausted\n"));
-                return;
-            }
             opt |= GET_CHMOD;
             break;
         case '2': /* --chgrp */
