@@ -20,9 +20,6 @@
 
 void cmd_help(int argc, char **argv)
 {
-#ifdef HAVE_LIBREADLINE
-	Function *func;
-#endif
 	int i;
 	listitem *li;
 
@@ -30,22 +27,22 @@ void cmd_help(int argc, char **argv)
 
   if(argc==2) {
     if(find_func(argv[1], false)) {
-     char *tmp = (char *)xmalloc(30);
-     sprintf(tmp, "%s --help", argv[1]);
-     exe_cmdline(tmp, false);
-     return;
-    }
-    else {
+      const size_t len = strlen(argv[1]) + 8;
+      char *tmp = xmalloc(len);
+      snprintf(tmp, len, "%s --help", argv[1]);
+      exe_cmdline(tmp, false);
+      return;
+    } else {
 			fprintf(stderr, _("No such command '%s'!\n\n"), argv[1]);
     }
   };
 
 	fprintf(stderr, _("Available commands: (commands may be abbreviated)\n"));
-#ifdef HAVE_LIBREADLINE
+#if defined(HAVE_LIBREADLINE) && !defined(HAVE_LIBEDIT)
 	/* hack to let readline display all commands */
 	rl_point=rl_end=0;
-	func = rl_named_function("possible-completions");
-	if(func)
+	Function* func = rl_named_function("possible-completions");
+	if (func)
 		func();
 	else {
 #endif
@@ -53,7 +50,7 @@ void cmd_help(int argc, char **argv)
 			printf("%s\n", cmds[i].cmd);
 		for(li = gvAliases->first; li; li = li->next)
 			printf("%s\n", ((alias *)li->data)->name);
-#ifdef HAVE_LIBREADLINE
+#if defined(HAVE_LIBREADLINE) && !defined(HAVE_LIBEDIT)
 	}
 #endif
 }
@@ -65,9 +62,13 @@ void cmd_version(int argc, char **argv)
 	printf(FULLVER "\n");
 
 	printf(_("Compiled " __TIME__ " " __DATE__ " (" HOSTTYPE ")\n"));
-#if HAVE_LIBREADLINE
+#ifdef HAVE_LIBEDIT
+  printf(_("Using editline version %s.\n"), rl_library_version);
+#else
+#ifdef HAVE_LIBREADLINE
 	printf(_("Using Readline version %s.\n"), rl_library_version);
 #endif
+#endif
 #ifdef HAVE_LIBSSH
 	printf(_("Using libssh version %d.%d.%d.\n"), LIBSSH_VERSION_MAJOR,
 			LIBSSH_VERSION_MINOR, LIBSSH_VERSION_MICRO);
