@@ -39,9 +39,14 @@
 # include <sys/types.h>
 #endif
 
+/* C99 headers */
 #include <stdint.h>
-
+#include <stdbool.h>
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
+
+
 #include <ctype.h>
 #include <signal.h>
 #include <stdarg.h>
@@ -54,9 +59,6 @@
 
 #include <sys/ioctl.h>
 
-#if defined HAVE_DECL_HERROR && !HAVE_DECL_HERROR
-void herror(const char *s);
-#endif
 #if defined HAVE_DECL_ASPRINTF && !HAVE_DECL_ASPRINTF
 int asprintf(char **strp, const char *format, ...) YAFC_PRINTF(2, 3);
 #endif
@@ -64,23 +66,6 @@ int asprintf(char **strp, const char *format, ...) YAFC_PRINTF(2, 3);
 int vasprintf(char **strp, const char *format, va_list ap);
 #endif
 
-#ifdef STDC_HEADERS
-# include <string.h>
-#else
-# ifndef HAVE_STRCHR
-#  define strchr index
-#  define strrchr rindex
-# endif
-char *strchr (), *strrchr ();
-# ifndef HAVE_MEMCPY
-#  define memcpy(d, s, n) bcopy ((s), (d), (n))
-#  define memmove(d, s, n) bcopy ((s), (d), (n))
-# endif
-#endif
-
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
@@ -89,6 +74,10 @@ char *strchr (), *strrchr ();
 # include <strings.h>
 #endif
 
+#ifdef HAVE_BSD_STRING_H
+#include <bsd/string.h>
+#endif
+
 #ifdef HAVE_UNAME
 # include <sys/utsname.h>
 #endif
@@ -142,7 +131,6 @@ char *strchr (), *strrchr ();
 # include <arpa/inet.h> /* for inet_aton() or inet_addr()  */
 #endif
 
-
 #ifdef HAVE_LIBREADLINE
 #  if defined(HAVE_READLINE_READLINE_H)
 #    include <readline/readline.h>
@@ -168,6 +156,11 @@ extern int read_history ();
   /* no history */
 #endif /* HAVE_READLINE_HISTORY */
 
+#ifdef HAVE_LIBEDIT
+#include <editline/readline.h>
+#define HAVE_LIBREADLINE
+#endif
+
 
 #ifdef HAVE_FNMATCH_GNU
 #include <fnmatch.h>
@@ -217,22 +210,6 @@ size_t strlcpy (char *dst, const char *src, size_t dst_sz);
 
 typedef void (*sighandler_t)(int);
 
-#ifndef HAVE_STDBOOL_H
-#include <stdbool.h>
-#else
-#if !HAVE__BOOL
-#ifdef __cplusplus
-typedef bool _Bool;
-#else
-typedef unsigned char _Bool;
-#endif
-#endif
-#define bool _Bool
-#define false 0
-#define true 1
-#define __bool_true_false_are_defined 1
-#endif
-
 #define test(a, b)   (((a) & (b)) == (b))
 #define STD_SHELL "/bin/sh"
 
